// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'dart:async';

import 'package:equatable/equatable.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:wyatt_cloud_messaging_bloc_base/src/domain/entities/remote_notifications.dart';
import 'package:wyatt_cloud_messaging_bloc_base/src/domain/usecases/listen_notification_use_case.dart';
import 'package:wyatt_cloud_messaging_bloc_base/src/domain/usecases/subscribe_to_notification_topic_use_case.dart';
import 'package:wyatt_cloud_messaging_bloc_base/src/domain/usecases/unsubscribe_from_notification_topic_use_case.dart';

part 'cloud_messaging_state.dart';

typedef OnNotification = void Function(RemoteNotification);

class CloudMessagingCubit extends Cubit<CloudmessagingState> {
  CloudMessagingCubit({
    required ListenNotificationUseCase listenNotification,
    SubscribeToNotificationTopicUseCase? subscribe,
    UnsubscribeFromNotificationTopicUseCase? unsubscribe,
    this.handleNotification,
  })  : _listenNotification = listenNotification,
        _subscribe = subscribe,
        _unsubscribe = unsubscribe,
        super(const CloudmessagingState());
  final ListenNotificationUseCase _listenNotification;
  final SubscribeToNotificationTopicUseCase? _subscribe;
  final UnsubscribeFromNotificationTopicUseCase? _unsubscribe;

  final OnNotification? handleNotification;

  Future<void> listenNotification() async {
    final notificaitons = await _listenNotification.execute();
    if (notificaitons.isOk) {
      notificaitons.ok?.listen((notification) {
        emit(CloudmessagingState(notification));
      });
    }
  }

  FutureOr<void> subscribe(String topic) => _subscribe?.execute(topic);

  FutureOr<void> unsubscribe(String topic) => _unsubscribe?.execute(topic);
}
