// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:bloc/bloc.dart';
import 'package:wyatt_continuous_deployment/src/core/task/task_cubit.dart';
import 'package:wyatt_continuous_deployment/src/core/utils/logging.dart';

class TaskObserver extends BlocObserver {
  @override
  void onChange(BlocBase<dynamic> bloc, Change<dynamic> change) {
    super.onChange(bloc, change);

    return switch (change.nextState) {
      TaskStateError(:final description) when description.isNotEmpty =>
        logger.err(description),
      TaskStateSucceed(:final description) when description.isNotEmpty =>
        logger.success(description),
      final TaskState taskState when taskState.description.isNotEmpty =>
        logger.detail(taskState.description),
      _ => logger.detail(change.nextState.toString()),
    };
  }
}
