// Copyright (C) 2024 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_architecture/wyatt_architecture.dart';
import 'package:wyatt_continuous_deployment/src/core/injection/injectable.dart';
import 'package:wyatt_continuous_deployment/src/domain/usecases/flutter/flutter_build_app_bundle_usecase.dart';
import 'package:wyatt_continuous_deployment/src/domain/usecases/flutter/flutter_build_ipa_usecase.dart';
import 'package:wyatt_continuous_deployment/src/domain/usecases/flutter/flutter_build_xcarchive_usecase.dart';
import 'package:wyatt_continuous_deployment/src/domain/usecases/flutter/flutter_clean_usecase.dart';
import 'package:wyatt_continuous_deployment/src/domain/usecases/flutter/flutter_pub_get_usecase.dart';

class Flutter {
  factory Flutter() => Flutter._(
        flutterCleanUsecase: getIt(),
        flutterPubGetUsecase: getIt(),
        flutterBuildXcarchiveUsecase: getIt(),
        flutterBuildIpaUsecase: getIt(),
        flutterBuildAppBundleUsecase: getIt(),
      );

  Flutter._({
    required FlutterCleanUsecase flutterCleanUsecase,
    required FlutterPubGetUsecase flutterPubGetUsecase,
    required FlutterBuildXcarchiveUsecase flutterBuildXcarchiveUsecase,
    required FlutterBuildIpaUsecase flutterBuildIpaUsecase,
    required FlutterBuildAppBundleUsecase flutterBuildAppBundleUsecase,
  })  : _flutterCleanUsecase = flutterCleanUsecase,
        _flutterPubGetUsecase = flutterPubGetUsecase,
        _flutterBuildXcarchiveUsecase = flutterBuildXcarchiveUsecase,
        _flutterBuildIpaUsecase = flutterBuildIpaUsecase,
        _flutterBuildAppBundleUsecase = flutterBuildAppBundleUsecase;

  final FlutterCleanUsecase _flutterCleanUsecase;
  final FlutterPubGetUsecase _flutterPubGetUsecase;
  final FlutterBuildXcarchiveUsecase _flutterBuildXcarchiveUsecase;
  final FlutterBuildIpaUsecase _flutterBuildIpaUsecase;
  final FlutterBuildAppBundleUsecase _flutterBuildAppBundleUsecase;

  FutureOrResult<void> clean() => _flutterCleanUsecase();
  FutureOrResult<void> getDependencies() => _flutterPubGetUsecase();
  FutureOrResult<void> createXcArchive() => _flutterBuildXcarchiveUsecase();
  FutureOrResult<void> buildIpa(List<String> args) =>
      _flutterBuildIpaUsecase(args);
  FutureOrResult<void> buildAppBundle(List<String> args) =>
      _flutterBuildAppBundleUsecase(args);
}
